@@ -29,6 +29,7 @@ _RAW_OPTION_LEVELS = {
         "PROJECT_NAME",
         "PROJECT_ROOT_DIR",
         "CONF_PROJECT_FILE",
+        "CONF_PROJECT_LOCAL_FILE",
         "TESTS_DIR",
         "HOOKS_DIR",
         "REPORTS_DIR",
@@ -44,11 +45,17 @@ _RAW_OPTION_LEVELS = {
         "DBAUTO_SQL_DIR",
         "CONF_DIR",
         "CONF_DATA_FILE",
+        "CONF_DATA_LOCAL_FILE",
         "CONF_ENVS_FILE",
+        "CONF_ENVS_LOCAL_FILE",
         "CONF_SESSIONS_FILE",
+        "CONF_SESSIONS_LOCAL_FILE",
         "CONF_STAGES_FILE",
+        "CONF_STAGES_LOCAL_FILE",
         "CONF_GROUPS_FILE",
+        "CONF_GROUPS_LOCAL_FILE",
         "CONF_WITHX_FILE",
+        "CONF_WITHX_LOCAL_FILE",
         "DATA_DIR",
         "DATA_SRC_DIR",
         "DATA_REF_DIR",
@@ -71,7 +78,7 @@ _RAW_OPTION_LEVELS = {
         "LOG_FILE_LEVEL",
         "LOG_CONSOLE_LEVEL",
         "REPORT_FORMATS",
-        "REPORT_GROUP_RENAME",
+        "REPORT_GROUP_RENAME"
     },
 
     ConfigStage.PROJECT: {
