@@ -190,4 +190,8 @@ class ContextualDataReference(metaclass=abc.ABCMeta):
 
     @abc.abstractmethod
     def _populate(self):
-        pass
\ No newline at end of file
+        pass
+
+    def as_json(self):
+        from arjuna import Json, Http
+        return Json.from_str(Http.content.json(self.named_values).content)
\ No newline at end of file
