@@ -24,4 +24,4 @@ class GuiPageSource(SingleGuiEntitySource):
     '''
 
     def __init__(self, raw_source):
-        super().__init__(raw_source, root_tag="html")
\ No newline at end of file
+        super().__init__(raw_source)
\ No newline at end of file
